#
# spec file for package snappy
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libsnappy1
Name:           snappy
Version:        1.1.10
Release:        1.2
Summary:        A compressor/decompressor library favoring time
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/google/snappy/
Source0:        https://github.com/google/snappy/archive/%{version}.tar.gz
Source1:        snappy.pc
Source99:       baselibs.conf
Patch0:         use-system-test-libs.patch
Patch2:         reenable-rtti.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  lzo-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(benchmark)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(zlib)

%description
Snappy is a compression/decompression library. It does not aim for maximum
compression, or compatibility with any other compression library; instead, it
aims for high speeds and reasonable compression.

%package -n %{libname}
Summary:        Shared library from snappy
Group:          System/Libraries

%description -n %{libname}
Snappy is a compression/decompression library. It does not aim for maximum
compression, or compatibility with any other compression library; instead, it
aims for high speeds and reasonable compression. For instance, compared to
the fastest mode of zlib, Snappy is an order of magnitude faster for most
inputs, but the resulting compressed files are anywhere from 20%% to 100%%
bigger. On a single core of a 1st-generation Core i7 processor in 64-bit
mode, Snappy compresses at about 250 MB/sec or more and decompresses at about
500 MB/sec or more.

This package holds the shared library of snappy.

%package devel
Summary:        Development files for snappy
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
Snappy is a compression/decompression library. It does not aim for maximum
compression, or compatibility with any other compression library; instead, it
aims for high speeds and reasonable compression.

This package holds the development files for snappy.

%prep
%autosetup

%build
%cmake -DSNAPPY_USE_BUNDLED_GTEST=OFF -DSNAPPY_USE_BUNDLED_BENCHMARK_LIB=OFF
%make_build

%install
%cmake_install
install -d -m 755 %{buildroot}%{_libdir}/pkgconfig
install -m 644 %{SOURCE1} %{buildroot}%{_libdir}/pkgconfig/%{name}.pc

%check
%ctest

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%{_libdir}/libsnappy.so.*

%files devel
%{_includedir}/snappy*.h
%{_libdir}/libsnappy.so
%dir %{_libdir}/cmake/Snappy/
%{_libdir}/cmake/Snappy/*
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.10:
  * Performance improvements
  * Compilation fixes for various environments
- drop fix-always-inline.patch (obsolete)
* Wed Oct 27 2021 Tim Serong <tserong@suse.com>
- Re-enable RTTI, without which other applications can't subclass
  snappy::Source (this breaks Ceph, as one example)
- Add reenable-rtti.patch
* Tue Jul 13 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 1.1.9:
  * Performance improvements
- Add fix-always-inline.patch
- Add use-system-test-libs.patch
- Add a hardcoded snappy.pc file
* Tue Aug 25 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.1.8:
  * Small performance improvements.
  * Removed snappy::string alias for std::string.
  * Improved CMake configuration.
- remove snappy-pcfile.patch (never went upstream)
* Thu Feb  8 2018 jengelh@inai.de
- Better neutrality of from description. Quantify "Core i7".
  Trim description of SRPM and -devel as the user already has an
  idea what to look for.
- Fix RPM groups.
* Thu Feb  8 2018 tchvatal@suse.com
- Version update to 1.1.7:
  * Aarch64 fixes
  * ppc speedups
  * PIE improvements
  * Switch to cmake build system
- Add patch snappy-pcfile.patch:
  * Pull 55 on upstream github, was dropped when moving to cmake
    of course we still need it
- Fix license install wrt bsc#1080040
* Sat Apr 15 2017 toddrme2178@gmail.com
- Version bump to 1.1.4
  * Fix a 1%% performance regression when snappy is used in PIE executables.
  * Improve compression performance by 5%%.
  * Improve decompression performance by 20%%.
- Use better download url.
* Wed Jul 29 2015 tchvatal@suse.com
- Version bump to 1.1.3:
  * See the NEWS file for full details
- Switch to distribution from github
- Remove upstreamed patch:
  * snappy-1.1.1-random-return.patch
* Wed Jul 29 2015 dimstar@opensuse.org
- Add baselibs.conf: build snappy1-32bit, as needed by
  libqt5-qtwebengine-32bit.
* Thu Sep 11 2014 toddrme2178@gmail.com
- Update to version 1.1.2
  - This is a maintenance release with no changes to the actual
    library source code.
  * Stop distributing benchmark data files that have unclear
    or unsuitable licensing.
  * Add support for padding chunks in the framing format.
* Wed Nov 13 2013 p.drouand@gmail.com
- Update to version 1.1.1
  * Add support for uncompressing to iovecs (scatter I/O).
  * Speed up decompression by ~2%%; much more so (~13-20%%) on
    a few benchmarks on given compilers and CPUs.
  * Fix a few issues with MSVC compilation.
  * Support truncated test data in the benchmark.
- Adapt patch to upstream changes
  * snappy-random-return.patch > snappy-1.1.1-random-return.patch
* Thu Aug 22 2013 cdenicolo@suse.com
- license update: BSD-3-Clause
  correct license is BSD-3-Clause.
* Thu Aug 15 2013 mvyskocil@suse.com
- Update to 1.1.0 (FATE#315420)
  * Snappy now uses 64 kB block size instead of 32 kB. On average,
    this means it compresses about 3%% denser (more so for some
    inputs), at the same or better speeds.
  * libsnappy no longer depends on iostream.
  * Some small performance improvements in compression on x86
    (0.5–1%%).
  * Various portability fixes for ARM-based platforms, for MSVC,
    and for GNU/Hurd.
- refresh and rename random-return.patch
  * snappy-random-return.patch
- reformat spec file
- build with NDEBUG to speedup a library
- install COPYING alongside so file
* Fri Nov 23 2012 mrueckert@suse.de
- update to 1.0.5
  * More speed improvements. Exactly how big will depend on
    the architecture:
  - 3–10%% faster decompression for the base case (x86-64).
  - ARMv7 and higher can now use unaligned accesses,
    and will see about 30%% faster decompression and
    20–40%% faster compression.
  - 32-bit platforms (ARM and 32-bit x86) will see 2–5%%
    faster compression.
    These are all cumulative (e.g., ARM gets all three speedups).
  * Fixed an issue where the unit test would crash on system
    with less than 256 MB address space available,
    e.g. some embedded platforms.
  * Added a framing format description, for use over e.g. HTTP,
    or for a command-line compressor. We do not have any
    implementations of this at the current point, but there seems
    to be enough of a general interest in the topic.
    Also make the format description slightly clearer.
  * Remove some compile-time warnings in -Wall
    (mostly signed/unsigned comparisons), for easier embedding
    into projects that use -Wall -Werror.
* Wed Feb  8 2012 mrueckert@suse.de
- initial package (v1.0.4)
